@@ -2,9 +2,13 @@
 from .microservice import Microservice
 from .database import Database
 from .bucket import Bucket
+from .ecs.cluster import ECSCluster
+from .ecs.microservice import ECSMicroservice
+from .efs.volume import EFSVolume
 from .api import API
 from .service_user_for_iac import ServiceUserForIAC
 from .service_user_for_static_assets import ServiceUserForStaticAssets
+from .load_balancer import Alb, Nlb
+from .security_group import SecurityGroup
 
-
-__version__ = '2.3.0'
+__version__ = '2.6.3'
