@@ -13,21 +13,25 @@ engine_to_cdk_engine = {
     "legacy-aurora-mysql": _rds.DatabaseClusterEngine.aurora,
     "aurora-mysql": _rds.DatabaseClusterEngine.aurora_mysql,
     "aurora-postgresql": _rds.DatabaseClusterEngine.aurora_postgres,
+    "aurora-postgresql_12": _rds.DatabaseClusterEngine.aurora_postgres,
     "oracle_s2": _rds.DatabaseInstanceEngine.oracle_se2,
     "oracle_ee": _rds.DatabaseInstanceEngine.oracle_ee,
     "mysql": _rds.DatabaseInstanceEngine.mysql,
     "postgresql": _rds.DatabaseInstanceEngine.postgres,
-    "sqlserver-se": _rds.DatabaseInstanceEngine.sql_server_se
+    "sqlserver-se": _rds.DatabaseInstanceEngine.sql_server_se,
+    "sqlserver-ex": _rds.DatabaseInstanceEngine.sql_server_ex
 }
 
 engine_to_cluster_parameter_group_family = {
     "legacy-aurora-mysql": "default.aurora5.6",
     "aurora-mysql": "default.aurora-mysql5.7",
     "aurora-postgresql": "default.aurora-postgresql9.6",
+    "aurora-postgresql_12": "default.aurora-postgresql12",
     "oracle_s2": "default.oracle-se2-19",
     "oracle_ee": "default.oracle-ee-19",
     "mysql": "default.mysql5.7",
-    "postgresql" : None
+    "postgresql" : None,
+    "sqlserver-ex": "default.sqlserver-ex-14.0",
 }
 
 engine_to_version_class = {
@@ -37,8 +41,10 @@ engine_to_version_class = {
     "oracle_s2": _rds.OracleEngineVersion,
     "oracle_ee": _rds.OracleEngineVersion,
     "aurora-postgresql": _rds.AuroraPostgresEngineVersion,
+    "aurora-postgresql_12": _rds.AuroraPostgresEngineVersion,
     "postgresql": _rds.PostgresEngineVersion,
     "sqlserver-se":  _rds.SqlServerEngineVersion,
+    "sqlserver-ex":  _rds.SqlServerEngineVersion,
 }
 
 class Database(Construct):
@@ -218,6 +224,7 @@ class Database(Construct):
 
         is_oracle = "oracle" in database_engine
         is_sqlserver = "sqlserver" in database_engine
+        is_sqlserver_ex = "sqlserver-ex" in database_engine
 
         has_no_parameter_group = parameter_group is None and database_cluster_parameters_group_name is None
         has_no_defult_parameter_group = has_no_parameter_group and engine_to_cluster_parameter_group_family[database_engine] is None
@@ -317,11 +324,15 @@ class Database(Construct):
         # ~~~~~~~~~~~~~~~~
         # KMS Encryption key
         # ~~~~~~~~~~~~~~~~
-        key_arn = account_id
-        key_arn = (
-            "arn:aws:kms:eu-west-1:" + account_id + ":key/" + aws_account["kms_rds_key"]
-        )
-        encryption_key = _kms.Key.from_key_arn(self, "encryption_key", key_arn)
+        # SQL Server Express does not support encryption
+        if not is_sqlserver_ex:
+            key_arn = account_id
+            key_arn = (
+                "arn:aws:kms:eu-west-1:" + account_id + ":key/" + aws_account["kms_rds_key"]
+            )
+            encryption_key = _kms.Key.from_key_arn(self, "encryption_key", key_arn)
+        else:
+            encryption_key = None
 
         # ~~~~~~~~~~~~~~~~
         # RDS Parameter group
@@ -467,6 +478,11 @@ class Database(Construct):
                 # Default SQL server license model is LICENSE_INCLUDED
                 license_model = _rds.LicenseModel.LICENSE_INCLUDED
 
+            if is_sqlserver_ex:
+                is_multi_az = False
+            else:                     
+                is_multi_az = True
+
             self._instance = _rds.DatabaseInstance(
                 self,
                 "instance",
@@ -485,7 +501,7 @@ class Database(Construct):
                 deletion_protection=is_production,
                 instance_identifier=identifier_prefix + "db",
                 # max_allocated_storage=None,
-                multi_az=is_production,
+                multi_az=is_multi_az,
                 option_group=None if has_no_option_group else option_group,
                 preferred_maintenance_window="mon:03:00-mon:04:00",
                 processor_features=None,
