@@ -65,6 +65,7 @@ class ServiceUserForIAC(Construct):
         kms_ssm_key = aws_account["kms_ssm_key"]
         kms_rds_key = aws_account["kms_rds_key"]
         kms_ebs_key = aws_account["kms_ebs_key"]
+        kms_vault_key = aws_account["kms_vault_key"]
 
         # S3 buckets 
         s3_buckets = [
@@ -96,6 +97,10 @@ class ServiceUserForIAC(Construct):
                 # Resource ALL
                 _iam.PolicyStatement(
                     actions=[
+                        "backup:CreateBackupPlan",
+                        "backup:CreateBackupSelection",
+                        "backup:DescribeBackupVault",
+                        "backup:CreateBackupVault",
                         "cloudformation:Describe*",
                         "cloudformation:ValidateTemplate",
                         "cloudformation:ExecuteChangeSet",
@@ -463,6 +468,37 @@ class ServiceUserForIAC(Construct):
                         "*"
                         ],
                     ),
+                # Relative to Backup
+                _iam.PolicyStatement(
+                    actions=[
+                        "backup:DeleteBackupPlan",
+                        "backup:DeleteBackupSelection",
+                        "backup:DeleteBackupVault",
+                    ],
+                    resources=["*"],
+                    conditions={
+                            "ForAnyValue:StringLike": {
+                                "ec2:ResourceTag/ApplicationName": app_name
+                            }
+                        },
+                ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "backup:DeleteBackupPlan",
+                        "backup:DeleteBackupSelection",
+                        "backup:DeleteBackupVault",
+                    ],
+                    resources=["*"],
+                    conditions={
+                            "ForAnyValue:StringLike": {
+                                "aws:ResourceTag/ApplicationName": app_name
+                            }
+                        },
+                ),
+                _iam.PolicyStatement(
+                    actions=["backup:DeleteBackupVault"],
+                    resources=["arn:aws:backup:eu-west-1:" + "*" + ":backup-vault:" + app_name + "*"],
+                ),
                 # Filter by SPECIFIC RESOURCE
                 _iam.PolicyStatement(
                     actions=[
@@ -478,6 +514,7 @@ class ServiceUserForIAC(Construct):
                         "arn:aws:kms:eu-west-1:" + account_id + ":key/" + kms_ebs_key,
                         "arn:aws:kms:eu-west-1:" + account_id + ":key/" + kms_rds_key,
                         "arn:aws:kms:eu-west-1:" + account_id + ":key/" + kms_ssm_key,
+                        "arn:aws:kms:eu-west-1:" + account_id + ":key/" + kms_vault_key,
                     ],
                 ),
                 _iam.PolicyStatement(
